==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/WebCancelableEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebCancelableEventArgsDetailDescriptionMetadata } from "./WebCancelableEventArgsDetailDescriptionMetadata";
import { WebCancelableEventArgsDescription } from "./WebCancelableEventArgsDescription";
/**
 * @hidden
 */
export let WebCancelableEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebCancelableEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebCancelableEventArgsDescriptionMetadata.a == null) {
                WebCancelableEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebCancelableEventArgsDescriptionMetadata.c(WebCancelableEventArgsDescriptionMetadata.a);
            }
            if (a.k(WebCancelableEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ab(WebCancelableEventArgsDescriptionMetadata.a);
            WebCancelableEventArgsDetailDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:CancelableEventArgs");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__marshalByValue", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("Detail", "ExportedType:WebCancelableEventArgsDetail");
        }
        static d(a) {
            WebCancelableEventArgsDescriptionMetadata.b(a);
            a.ad("WebCancelableEventArgs", () => new WebCancelableEventArgsDescription());
            a.ac("WebCancelableEventArgs", WebCancelableEventArgsDescriptionMetadata.a);
        }
    }
    WebCancelableEventArgsDescriptionMetadata.$t = markType(WebCancelableEventArgsDescriptionMetadata, 'WebCancelableEventArgsDescriptionMetadata');
    WebCancelableEventArgsDescriptionMetadata.a = null;
    return WebCancelableEventArgsDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/WebCancelableEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebCancelableEventArgsDetailDescriptionMetadata } from "./WebCancelableEventArgsDetailDescriptionMetadata";
import { WebCancelableEventArgsDescription } from "./WebCancelableEventArgsDescription";
/**
 * @hidden
 */
export let WebCancelableEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebCancelableEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebCancelableEventArgsDescriptionMetadata.a == null) {
                WebCancelableEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebCancelableEventArgsDescriptionMetadata.c(WebCancelableEventArgsDescriptionMetadata.a);
            }
            if (a.k(WebCancelableEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebCancelableEventArgsDescriptionMetadata.a);
            WebCancelableEventArgsDetailDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:CancelableEventArgs");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__marshalByValue", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("Detail", "ExportedType:WebCancelableEventArgsDetail");
        }
        static d(a) {
            WebCancelableEventArgsDescriptionMetadata.b(a);
            a.ae("WebCancelableEventArgs", () => new WebCancelableEventArgsDescription());
            a.ad("WebCancelableEventArgs", WebCancelableEventArgsDescriptionMetadata.a);
        }
    }
    WebCancelableEventArgsDescriptionMetadata.$t = markType(WebCancelableEventArgsDescriptionMetadata, 'WebCancelableEventArgsDescriptionMetadata');
    WebCancelableEventArgsDescriptionMetadata.a = null;
    return WebCancelableEventArgsDescriptionMetadata;
})();
